.. episcanpy documentation master file, created by
   sphinx-quickstart on Thu Jan 17 14:08:45 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Report issues and see the code on `GitHub <https://github.com/AnnaDanese/episcanpy>`__.

If Scanpy is useful for your research, consider citing `Genome Biology (2018) <https://doi.org/10.1186/s13059-017-1382-0>`__.
When Episcanpy is released... Well cite Episcanpy too.

.. include:: release_notes.rst

.. put references first so all references are resolved
.. NO! there is a particular meaning to this sequence
.. toctree::
   :maxdepth: 1
   :hidden:

   examples
   basic_usage
   installation
   
